"""
Module containing errors generated by Atramhasis.
"""

from pyramid.httpexceptions import HTTPNotFound


class SkosRegistryNotFoundException(Exception):
    """
    Atramhasis could not find a SKOS registry.
    """

    def __init__(
        self, value="No SKOS registry found, please check your application setup"
    ):
        self.value = value

    def __str__(self):
        return repr(self.value)


class ConceptSchemeNotFoundException(HTTPNotFound):
    """
    A ConceptScheme could not be found.
    """

    def __init__(self, scheme_id):
        self.value = "No conceptscheme found with the given id " + scheme_id
        super().__init__(detail=self.value)

    def __str__(self):
        return repr(self.value)


class LanguageNotFoundException(HTTPNotFound):
    """
    A Language could not be found.
    """

    def __init__(self, scheme_id):
        self.value = "No language found with the given id " + scheme_id
        super().__init__(detail=self.value)

    def __str__(self):
        return repr(self.value)


class ConceptNotFoundException(HTTPNotFound):
    """
    A Concept or Collection could not be found.
    """

    def __init__(self, c_id):
        self.value = "No concept found with the given id " + c_id
        super().__init__(detail=self.value)

    def __str__(self):
        return repr(self.value)


class ValidationError(Exception):
    """
    Some data that was validated is invalid.
    """

    def __init__(self, value, errors):
        self.value = value
        self.errors = errors

    def __str__(self):
        return repr(self.value)


class DbNotFoundException(Exception):
    """
    Atramhasis could not find a database.
    """

    def __init__(self, value="No database found, please check your application setup"):
        self.value = value

    def __str__(self):
        return repr(self.value)


class SQLAlchemyProviderNotFoundException(HTTPNotFound):
    """
    SQLAlchemyProvider could not be found in the database.
    """

    def __init__(self, p_id):
        self.value = "No SQLAlchemyProvider found with the given id " + p_id

    def __str__(self):
        return repr(self.value)



import logging

from pyramid.response import Response

from atramhasis.data.models import ConceptVisitLog
from atramhasis.data.models import ConceptschemeVisitLog

log = logging.getLogger(__name__)


def _origin_from_request(request):
    if '.csv' in request.url:
        return 'CSV'
    elif 'text/html' in request.accept:
        return 'HTML'
    elif 'application/json' in request.accept:
        return 'REST'
    elif 'application/ld+json' in request.accept:
        return 'RDF'
    else:
        return None


def _origin_from_response(response):
    if response.content_type == 'application/rdf+xml' \
            or response.content_type == 'application/ld+json' \
            or response.content_type == 'text/turtle' \
            or response.content_type == 'application/x-turtle':
        return 'RDF'
    else:
        return None


def audit(fn):
    """
    use this decorator to audit an operation and to log the visit
    external conceptschemes won't be logged

    * CSV routes with .csv extensions accept all mime types,
      the response is not of the `pyramid.response.Response` type,
      the origin is derived from the `pyramid.request.Request.url` extension.
    * RDF routes with .rdf, .ttl extensions accept all mime types,
      the origin is derived form the response content type.
    * REST and HTML the view results are not of the `pyramid.response.Response` type,
      the origin is derived from the accept header.
    """

    def advice(parent_object, *args, **kw):
        request = parent_object.request
        audit_manager = request.data_managers['audit_manager']

        if 'scheme_id' not in request.matchdict.keys():
            log.error('Misuse of the audit decorator. The url must at least contain a {scheme_id} parameter')
            return fn(parent_object, *args, **kw)

        provider = request.skos_registry.get_provider(request.matchdict['scheme_id'])
        if not provider or 'external' in provider.get_metadata()['subject']:
            return fn(parent_object, *args, **kw)
        else:
            if 'c_id' in request.matchdict.keys():
                visit_log = ConceptVisitLog(
                    concept_id=request.matchdict['c_id'],
                    conceptscheme_id=request.matchdict['scheme_id']
                )
            else:
                visit_log = ConceptschemeVisitLog(conceptscheme_id=request.matchdict['scheme_id'])
            response = fn(parent_object, *args, **kw)

            if isinstance(response, Response):
                visit_log.origin = _origin_from_response(response)
            else:
                visit_log.origin = _origin_from_request(request)

            audit_manager.save(visit_log)

        return response

    return advice



import copy
import csv
from io import StringIO

from pyramid.renderers import JSON
from pyramid_skosprovider.renderers import collection_adapter as skos_collection_adapter
from pyramid_skosprovider.renderers import concept_adapter as skos_concept_adapter
from pyramid_skosprovider.renderers import label_adapter as skos_label_adapter
from pyramid_skosprovider.renderers import note_adapter as skos_note_adapter
from pyramid_skosprovider.renderers import source_adapter as skos_source_adapter
from skosprovider.providers import VocabularyProvider
from skosprovider.skos import Collection as SkosCollection
from skosprovider.skos import Concept as SkosConcept
from skosprovider.skos import Label as SkosLabel
from skosprovider.skos import Note as SkosNote
from skosprovider.skos import Source as SkosSource
from skosprovider_sqlalchemy.models import Collection
from skosprovider_sqlalchemy.models import Concept
from skosprovider_sqlalchemy.models import ConceptScheme
from skosprovider_sqlalchemy.models import Label
from skosprovider_sqlalchemy.models import Language
from skosprovider_sqlalchemy.models import Note
from skosprovider_sqlalchemy.models import Source
from skosprovider_sqlalchemy.providers import SQLAlchemyProvider

from atramhasis.data.models import IDGenerationStrategy


class CSVRenderer:
    def __init__(self, info):
        pass

    def __call__(self, value, system):
        f_out = StringIO()
        writer = csv.writer(f_out, delimiter=',', quoting=csv.QUOTE_ALL)

        writer.writerow(value['header'])
        writer.writerows(value['rows'])

        resp = system['request'].response
        resp.content_type = 'text/csv'
        resp.content_disposition = 'attachment;filename="' + value['filename'] + '.csv"'
        return f_out.getvalue()


json_renderer_verbose = JSON()


def conceptscheme_adapter(obj, request):
    """
    Adapter for rendering a :class:`skosprovider_sqlalchemy.models.ConceptScheme` to json

    :param skosprovider_sqlalchemy.models.ConceptScheme obj: The conceptscheme to be rendered.
    :param request: the current request
    :rtype: :class:`dict`
    """
    scheme_id = request.matchdict['scheme_id']
    provider = request.skos_registry.get_provider(scheme_id)
    language = request.params.get('language', request.locale_name)
    label = obj.label(language)
    return {
        'id': obj.id,
        'uri': obj.uri,
        'label': label.label if label else None,
        'subject': provider.metadata['subject'] if provider.metadata['subject'] else [],
        'labels': obj.labels,
        'notes': obj.notes,
        'languages': obj.languages,
        'sources': obj.sources
    }


def concept_adapter(obj, request):
    """
    Adapter for rendering a :class:`skosprovider_sqlalchemy.models.Concept` to json with verbose relations.

    :param skosprovider_sqlalchemy.models.Concept obj: The concept to be rendered.
    :param request: the current request
    :rtype: :class:`dict`
    """
    matches = {}
    for m in obj.matches:
        key = m.matchtype.name[:m.matchtype.name.find('Match')]
        if key not in matches:
            matches[key] = []
        matches[key].append(m.uri)
    language = request.params.get('language', request.locale_name)
    label = obj.label(language)
    return {
        'id': obj.concept_id,
        'type': obj.type,
        'uri': obj.uri,
        'label': label.label if label else None,
        'labels': obj.labels,
        'notes': obj.notes,
        'sources': obj.sources,
        'broader': [map_relation(c, language) for c in obj.broader_concepts],
        'narrower': [map_relation(c, language) for c in obj.narrower_concepts],
        'related': [map_relation(c, language) for c in obj.related_concepts],
        'member_of': [map_relation(c, language) for c in obj.member_of],
        'subordinate_arrays': [map_relation(c, language) for c in obj.narrower_collections],
        'matches': matches
    }


def collection_adapter(obj, request):
    """
    Adapter for rendering a :class:`skosprovider_sqlalchemy.models.Collection` to json with verbose relations.

    :param skosprovider_sqlalchemy.models.Collection obj: The collection to be rendered.
    :param request: the current request
    :rtype: :class:`dict`
    """
    language = request.params.get('language', request.locale_name)
    label = obj.label(language)
    return {
        'id': obj.concept_id,
        'type': obj.type,
        'uri': obj.uri,
        'label': label.label if label else None,
        'notes': obj.notes,
        'labels': obj.labels,
        'sources': obj.sources,
        'members': [map_relation(c, language) for c in obj.members],
        'member_of': [map_relation(c, language) for c in obj.member_of],
        'superordinates': [map_relation(c, language) for c in obj.broader_concepts],
        'infer_concept_relations': obj.infer_concept_relations
    }


def map_relation(thing, language='any'):
    """
    Map thing in a relation, leaving out the relations (to avoid circular dependencies)
    :param thing: the thing to map
    :param language: language to use for the label
    :rtype: :class:`dict`
    """
    label = thing.label(language)
    return {
        'id': thing.concept_id,
        'type': thing.type,
        'uri': thing.uri,
        'label': label.label if label else None
    }


def label_adapter(obj, request):
    """
    Adapter for rendering a :class:`skosprovider_sqlalchemy.models.Label` to json.

    :param skosprovider_sqlalchemy.models.Label obj: The label to be rendered.
    :param request: the current request
    :rtype: :class:`dict`
    """
    return {
        'label': obj.label,
        'type': obj.labeltype_id,
        'language': obj.language_id
    }


def note_adapter(obj, request):
    """
    Adapter for rendering a :class:`skosprovider_sqlalchemy.models.Note` to json.

    :param skosprovider_sqlalchemy.models.Note obj: The note to be rendered.
    :param request: the current request
    :rtype: :class:`dict`
    """
    return {
        'note': obj.note,
        'type': obj.notetype_id,
        'language': obj.language_id
    }


def source_adapter(obj, request):
    """
    Adapter for rendering a :class:`skosprovider_sqlalchemy.models.Source` to json.

    :param skosprovider_sqlalchemy.models.Source obj: The source to be rendered.
    :param request: the current request
    :rtype: :class:`dict`
    """
    return {
        'citation': obj.citation
    }


def language_adaptor(obj, request):
    """
    Adapter for rendering a :class:`skosprovider_sqlalchemy.models.Language` to json.

    :param skosprovider_sqlalchemy.models.Language obj: The language to be rendered.
    :param request: the current request
    :rtype: :class:`dict`
    """
    return {
        'id': obj.id,
        'name': obj.name
    }


def provider_adapter(provider: VocabularyProvider, *_):
    if provider.uri_generator:
        uri_pattern = provider.uri_generator.pattern
    else:
        uri_pattern = None

    metadata = copy.deepcopy(provider.metadata)
    metadata.pop('id', None)
    metadata.pop('conceptscheme_id', None)
    data = {
        'id': provider.metadata['id'],
        'type': provider.__class__.__name__,
        'conceptscheme_uri': provider.concept_scheme.uri,
        'uri_pattern': uri_pattern,
        'default_language': metadata.pop("default_language", None),
        'subject': metadata.pop("subject", None),
        'force_display_language': metadata.pop("atramhasis.force_display_language", None),
        'metadata': metadata,
    }
    return data


def sa_provider_adapter(provider: SQLAlchemyProvider, *args):
    data = provider_adapter(provider, *args)
    strategy = data["metadata"].pop(
       "atramhasis.id_generation_strategy", IDGenerationStrategy.NUMERIC
    )
    data['id_generation_strategy'] = strategy.name
    data['expand_strategy'] = provider.expand_strategy
    return data


json_renderer_verbose.add_adapter(ConceptScheme, conceptscheme_adapter)
json_renderer_verbose.add_adapter(Concept, concept_adapter)
json_renderer_verbose.add_adapter(Collection, collection_adapter)
json_renderer_verbose.add_adapter(Label, label_adapter)
json_renderer_verbose.add_adapter(Note, note_adapter)
json_renderer_verbose.add_adapter(Source, source_adapter)
json_renderer_verbose.add_adapter(Language, language_adaptor)
json_renderer_verbose.add_adapter(SkosConcept, skos_concept_adapter)
json_renderer_verbose.add_adapter(SkosCollection, skos_collection_adapter)
json_renderer_verbose.add_adapter(SkosLabel, skos_label_adapter)
json_renderer_verbose.add_adapter(SkosNote, skos_note_adapter)
json_renderer_verbose.add_adapter(SkosSource, skos_source_adapter)
json_renderer_verbose.add_adapter(VocabularyProvider, provider_adapter)
json_renderer_verbose.add_adapter(SQLAlchemyProvider, sa_provider_adapter)



"""visit_log

Revision ID: 1ad2b6fbcf22
Revises: 441c5a16ef8
Create Date: 2015-07-27 13:29:04.840631

"""

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "1ad2b6fbcf22"
down_revision = "441c5a16ef8"


def upgrade():
    op.create_table(
        "conceptscheme_visit_log",
        sa.Column("id", sa.Integer(), primary_key=True, autoincrement=True),
        sa.Column("conceptscheme_id", sa.String(), nullable=False),
        sa.Column("visited_at", sa.DateTime(), nullable=False),
        sa.Column("origin", sa.String, nullable=False),
    )
    op.create_table(
        "concept_visit_log",
        sa.Column("id", sa.Integer(), primary_key=True, autoincrement=True),
        sa.Column("concept_id", sa.Integer(), nullable=False),
        sa.Column("conceptscheme_id", sa.String(), nullable=False),
        sa.Column("visited_at", sa.DateTime(), nullable=False),
        sa.Column("origin", sa.String, nullable=False),
    )


def downgrade():
    op.drop_table("concept_visit_log")
    op.drop_table("conceptscheme_visit_log")



"""
Module containing utility functions dealing with RDF used by Atramhasis.

.. versionadded:: 0.6.0
"""

from pyramid.settings import asbool
from rdflib import Graph
from rdflib import DCTERMS
from rdflib import FOAF
from rdflib import Namespace
from rdflib import RDF
from rdflib import SKOS
from rdflib import VOID
from rdflib.term import BNode
from rdflib.term import Literal
from rdflib.term import URIRef
from skosprovider_rdf.utils import _add_labels

FORMATS = Namespace('http://www.w3.org/ns/formats/')
SKOS_THES = Namespace('http://purl.org/iso25964/skos-thes#')
HYDRA = Namespace('http://www.w3.org/ns/hydra/core#')


def void_dumper(request, registry):
    """
    Creates a void file with information about all void Datasets in this Atramhasis instance.

    :param request: pyramid.request.Request request
    :param registry: skosprovider.registry.Registry
    """
    providers = [
        x for x in registry.get_providers()
        if not any([not_shown in x.get_metadata()['subject'] for not_shown in ['external']])
    ]
    graph = Graph()
    graph.namespace_manager.bind("void", VOID)
    graph.namespace_manager.bind("dcterms", DCTERMS)
    graph.namespace_manager.bind("foaf", FOAF)
    graph.namespace_manager.bind("skos", SKOS)
    graph.namespace_manager.bind("skos-thes", SKOS_THES)
    graph.namespace_manager.bind("hydra", HYDRA)
    duri = request.route_url('atramhasis.rdf_void_turtle_ext', _anchor='atramhasis')
    dataset = URIRef(duri)
    graph.add((dataset, RDF.type, VOID.Dataset))
    graph.add((dataset, FOAF.homepage, URIRef(request.route_url('home'))))
    graph.add((dataset, VOID.vocabulary, URIRef(DCTERMS)))
    graph.add((dataset, VOID.vocabulary, URIRef(SKOS)))
    graph.add((dataset, VOID.vocabulary, URIRef(SKOS_THES)))
    ldf_enabled = asbool(request.registry.settings.get('atramhasis.ldf.enabled'))
    ldf_baseurl = request.registry.settings.get('atramhasis.ldf.baseurl')
    if ldf_enabled and ldf_baseurl:
        ldfurl = ldf_baseurl + '/composite{?s,p,o}'
        _add_ldf_server(graph, dataset, ldfurl)
    for p in providers:
        _add_provider(graph, p, dataset, request)
    return graph


def _add_provider(graph, provider, dataseturi, request):
    """
    :param rdflib.graph.Graph graph: Graph that will contain the Dataset.
    :param skosprovider.providers.VocabularyProvider provider: Provider to turn into a Dataset.
    :param rdflib.term.URIRef dataseturi: URI of the main dataset this provider will be attached to.
    :param pyramid.request.Request request:
    :rtype: :class:`rdflib.graph.Graph`
    """
    pid = provider.get_vocabulary_id()
    metadataset = provider.get_metadata().get('dataset', {})
    duri = metadataset.get(
        'uri',
        request.route_url('atramhasis.rdf_void_turtle_ext', _anchor=pid)
    )
    pd = URIRef(duri)
    graph.add((pd, RDF.type, VOID.Dataset))
    graph.add((dataseturi, VOID.subset, pd))
    graph.add((pd, DCTERMS.identifier, Literal(pid)))
    graph.add((pd, VOID.rootResource, URIRef(provider.concept_scheme.uri)))
    graph.add((pd, FOAF.homepage, URIRef(request.route_url('skosprovider.conceptscheme', scheme_id=pid))))
    _add_labels(graph, provider.concept_scheme, pd)
    _add_metadataset(graph, pd, metadataset)
    fmap = [
        ('rdf', FORMATS.RDF_XML, 'skosprovider.conceptscheme.cs.rdf'),
        ('ttl', FORMATS.Turtle, 'skosprovider.conceptscheme.cs.ttl')
    ]
    for f in fmap:
        graph.add((pd, VOID.feature, f[1]))
        dump_url = request.route_url(f[2], scheme_id=pid)
        graph.add((pd, VOID.dataDump, URIRef(dump_url)))

    ldf_enabled = asbool(request.registry.settings.get('atramhasis.ldf.enabled'))
    ldf_baseurl = request.registry.settings.get('atramhasis.ldf.baseurl')
    if ldf_enabled and ldf_baseurl:
        pid = provider.get_vocabulary_id()
        ldfurl = ldf_baseurl + '/' + pid + '{?s,p,o}'
        _add_ldf_server(graph, pd, ldfurl)
    return graph


def _add_metadataset(graph, subject, metadataset):
    """
    :param rdflib.graph.Graph graph: Graph that contains the Dataset.
    :param rdflib.term.URIRef subject: Uri of the Dataset.
    :param dict metadataset: Dictionary with metadata to add to the Dataset.
    :rtype: :class:`rdflib.graph.Graph`
    """
    mapping = {
        'creator': {
            'predicate': DCTERMS.creator,
            'objecttype': URIRef
        },
        'publisher': {
            'predicate': DCTERMS.publisher,
            'objecttype': URIRef
        },
        'contributor': {
            'predicate': DCTERMS.contributor,
            'objecttype': URIRef
        },
        'language': {
            'predicate': DCTERMS.language
        },
        'date': {
            'predicte': DCTERMS.date
        },
        'created': {
            'predicate': DCTERMS.created
        },
        'issued': {
            'predicate': DCTERMS.issued
        },
        'license': {
            'predicate': DCTERMS.license,
            'objecttype': URIRef
        }
    }

    for k, v in mapping.items():
        if k in metadataset:
            if 'objecttype' in v:
                objecttype = v['objecttype']
            else:
                objecttype = Literal
            for ko in metadataset[k]:
                o = objecttype(ko)
                graph.add((subject, v['predicate'], o))
    return graph


def _add_ldf_server(graph, dataseturi, ldfurl):
    """
    :param rdflib.graph.Graph graph: Graph that contains the Dataset.
    :param rdflib.term.URIRef dataseturi: Uri of the Dataset.
    :param str ldfurl: Url pointing to the ldf server.
    :rtype: :class:`rdflib.graph.Graph`
    """
    ldf = BNode()
    graph.add((dataseturi, HYDRA.search, ldf))
    graph.add((ldf, HYDRA.template, Literal(ldfurl)))
    s = BNode()
    graph.add((s, HYDRA.variable, Literal('s')))
    graph.add((s, HYDRA.property, RDF.subject))
    graph.add((ldf, HYDRA.mapping, s))
    p = BNode()
    graph.add((p, HYDRA.variable, Literal('p')))
    graph.add((p, HYDRA.property, RDF.predicate))
    graph.add((ldf, HYDRA.mapping, p))
    o = BNode()
    graph.add((o, HYDRA.variable, Literal('o')))
    graph.add((o, HYDRA.property, RDF.object))
    graph.add((ldf, HYDRA.mapping, o))
    return graph



from skosprovider.registry import Registry
from skosprovider_sqlalchemy.models import ConceptScheme
from skosprovider_sqlalchemy.providers import SQLAlchemyProvider
from sqlalchemy import select

import tests
from atramhasis.data.models import ExpandStrategy
from atramhasis.data.models import IDGenerationStrategy
from atramhasis.data.models import Provider
from atramhasis.scripts import migrate_sqlalchemy_providers
from tests import DbTest


def setUpModule():
    tests.setup_db(guarantee_empty=True)
    tests.fill_db()


class TestMigrateTests(DbTest):
    def test_migrate(self):
        conceptscheme = ConceptScheme(uri='urn:x-skosprovider:trees')
        self.session.add(conceptscheme)
        self.session.flush()

        db_providers = self.session.execute(select(Provider)).scalars().all()
        self.assertEqual(0, len(db_providers))

        registry = Registry()
        registry.register_provider(
            SQLAlchemyProvider(
                {"id": "EXTRA", "conceptscheme_id": conceptscheme.id}, self.session
            )
        )
        other_providers = migrate_sqlalchemy_providers.get_atramhasis_sqlalchemy_providers(
            self.session
        )
        for provider in other_providers:
            if self.session.get(ConceptScheme, provider.conceptscheme_id) is None:
                self.session.add(
                    ConceptScheme(
                        id=provider.conceptscheme_id,
                        uri=f'urn:x-skosprovider:{provider.conceptscheme_id}'
                    )
                )
        self.session.flush()

        migrate_sqlalchemy_providers.migrate(
            skos_registry=registry,
            session=self.session,
        )

        db_providers = self.session.execute(select(Provider)).scalars().all()
        db_conceptscheme_ids = [p.conceptscheme_id for p in db_providers]
        expected_conceptscheme_ids = [1, 2, 3, 4, 5, 6, 7, 8, 9, conceptscheme.id]
        for expected in expected_conceptscheme_ids:
            self.assertIn(expected, db_conceptscheme_ids)
        provider = next(p for p in db_providers if p.conceptscheme_id == conceptscheme.id)
        self.assertEqual(conceptscheme.id, provider.conceptscheme_id)
        self.assertEqual(ExpandStrategy.RECURSE, provider.expand_strategy)
        self.assertEqual(IDGenerationStrategy.NUMERIC, provider.id_generation_strategy)
        self.assertEqual('urn:x-skosprovider:%s:%s', provider.uri_pattern)
        self.assertEqual(
            {
                'id': 'EXTRA',
                'subject': [],
                'atramhasis.id_generation_strategy': 'NUMERIC'
            },
            provider.meta
        )



"""
Testdata cotaining stylistic (eg. Gothic, Romanesque) and cultural periods 
(eg. La Tène)

.. versionadded:: 0.2.0
"""


from skosprovider.providers import DictionaryProvider
from skosprovider.uri import UriPatternGenerator
from .stijl_data import STIJLDATA

styles_and_cultures = DictionaryProvider(
    {'id': 'STYLE'},
    STIJLDATA,
    uri_generator=UriPatternGenerator('https://id.erfgoed.net/thesauri/stijlen_en_culturen/%s')
)



import json
import logging
import optparse
import os
import sys
import textwrap
import time

from pyramid.paster import bootstrap
from pyramid.paster import setup_logging

from atramhasis.errors import SkosRegistryNotFoundException

log = logging.getLogger(__name__)


def main():
    description = """\
    Generate a config file for a LDF server.
    """
    usage = "usage: %prog config_uri"
    parser = optparse.OptionParser(usage=usage, description=textwrap.dedent(description))
    parser.add_option(
        "-l",
        "--location",
        dest="config_location",
        type="string",
        help=(
            "Specify where to put the config file. If not specified, this is set to the"
            " atramhasis.ldf.config_location from your ini file."
        ),
    )

    options, args = parser.parse_args(sys.argv[1:])

    if not len(args) >= 1:
        log.error("You must provide at least one argument.")
        return 2

    config_uri = args[0]

    env = bootstrap(config_uri)
    setup_logging(config_uri)

    config_location = options.config_location
    if config_location is None:
        config_location = env["registry"].settings.get(
            "atramhasis.ldf.config_location", os.path.abspath(os.path.dirname(config_uri))
        )

    dump_location = env["registry"].settings.get(
        "atramhasis.dump_location", os.path.abspath(os.path.dirname(config_uri))
    )

    ldf_baseurl = env["registry"].settings.get("atramhasis.ldf.baseurl", None)

    ldf_protocol = env["registry"].settings.get("atramhasis.ldf.protocol", None)

    request = env["request"]

    if hasattr(request, "skos_registry") and request.skos_registry is not None:
        skos_registry = request.skos_registry
    else:
        raise SkosRegistryNotFoundException()  # pragma: no cover

    start_time = time.time()
    ldfconfig = {
        "@context": "https://linkedsoftwaredependencies.org/bundles/npm/@ldf/server/^3.0.0/components/context.jsonld",
        "@id": "urn:ldf-server:my",
        "import": "preset-qpf:config-defaults.json",
        "title": "Atramhasis LDF server",
        "datasources": [],
        "prefixes": [
            {"prefix": "rdf", "uri": "http://www.w3.org/1999/02/22-rdf-syntax-ns#"},
            {"prefix": "rdfs", "uri": "http://www.w3.org/2000/01/rdf-schema#"},
            {"prefix": "owl", "uri": "http://www.w3.org/2002/07/owl#"},
            {"prefix": "xsd", "uri": "http://www.w3.org/2001/XMLSchema#"},
            {"prefix": "hydra", "uri": "http://www.w3.org/ns/hydra/core#"},
            {"prefix": "void", "uri": "http://rdfs.org/ns/void#"},
            {"prefix": "skos", "uri": "http://www.w3.org/2004/02/skos/core#"},
            {"prefix": "skos-thes", "uri": "http://purl.org/iso25964/skos-thes#"},
        ],
    }

    if ldf_baseurl:
        ldfconfig["baseURL"] = ldf_baseurl

    if ldf_protocol:
        ldfconfig["protocol"] = ldf_protocol

    pids = []
    for p in skos_registry.get_providers():
        if any([not_shown in p.get_metadata()['subject'] for not_shown in ['external']]):
            continue
        pid = p.get_metadata()["id"]
        title = p.concept_scheme.label().label if p.concept_scheme.label() else pid
        pids.append(pid)
        filename = os.path.join(dump_location, "%s-full" % pid)
        dumptype = "HdtDatasource"
        filetype = "hdtFile"
        dumpfile = filename + ".hdt"

        if not os.path.isfile(dumpfile):
            dumptype = "TurtleDatasource"
            filetype = "file"
            dumpfile = filename + ".ttl"

        sourceconfig = {
            "@id": f"urn:ldf-server:myDatasource{pid}",
            "@type": dumptype,
            "quads": False,  # TODO
            "datasourcePath": pid,
            "datasourceTitle": title,
            filetype: dumpfile,
        }

        for n in p.concept_scheme.notes:
            if n.type in ["definition", "scopeNote"]:
                sourceconfig["description"] = n.note
                break

        ldfconfig["datasources"].append(sourceconfig)

    if len(pids):
        composite_sourceconfig = {
            "@id": "urn:ldf-server:myDatasourcecomposite",
            "@type": "CompositeDatasource",
            "quads": False,  # TODO
            "datasourcePath": "composite",
            "datasourceTitle": "All conceptschemes",
            "description": (
                "All conceptschemes contained in this Atramhasis instance together."
            ),
            "compose": [f"urn:ldf-server:myDatasource{pid}" for pid in pids],
        }
        ldfconfig["datasources"].append(composite_sourceconfig)

    config_filename = os.path.join(config_location, "ldf_server_config.json")

    with open(config_filename, "w") as fp:
        json.dump(ldfconfig, fp, indent=4)

    log.info(f'Config written to {config_filename}.')

    log.info(f'--- {(time.time() - start_time)} seconds ---;')

    env["closer"]()



"""
Testdata cotaining two very simple conceptschemes: trees and a few geographic concepts.

.. versionadded:: 0.1.0
"""

from skosprovider.providers import DictionaryProvider
from skosprovider.uri import UriPatternGenerator

larch = {
    'id': '1',
    'uri': 'urn:x-skosprovider:trees/1',
    'labels': [
        {'type': 'prefLabel', 'language': 'en', 'label': 'The Larch'},
        {'type': 'prefLabel', 'language': 'nl', 'label': 'De Lariks'},
        {'type': 'sortLabel', 'language': 'nl', 'label': 'c'},
    ],
    'notes': [{'type': 'definition', 'language': 'en', 'note': 'A type of tree.'}],
    'matches': {
        'close': ['https://id.python.org/different/types/of/trees/nr/1/the/larch']
    },
}

chestnut = {
    'id': '2',
    'uri': 'urn:x-skosprovider:trees/2',
    'labels': [
        {'type': 'prefLabel', 'language': 'en', 'label': 'The Chestnut'},
        {'type': 'altLabel', 'language': 'nl', 'label': 'De Paardekastanje'},
        {'type': 'altLabel', 'language': 'fr', 'label': 'la châtaigne'},
        {'type': 'sortLabel', 'language': 'nl', 'label': 'a'},
    ],
    'notes': [
        {'type': 'definition', 'language': 'en', 'note': 'A different type of tree.'}
    ],
    'matches': {
        'related': [
            'https://id.python.org/different/types/of/trees/nr/17/the/other/chestnut'
        ]
    },
}

species = {
    'id': 3,
    'uri': 'urn:x-skosprovider:trees/3',
    'labels': [
        {'type': 'prefLabel', 'language': 'en', 'label': 'Trees by species'},
        {'type': 'prefLabel', 'language': 'nl', 'label': 'Bomen per soort'},
        {'type': 'sortLabel', 'language': 'nl', 'label': 'b'},
    ],
    'type': 'collection',
    'members': ['1', '2'],
}

trees = DictionaryProvider(
    {'id': 'TREES', 'default_language': 'nl', 'conceptscheme_id': 1},
    [larch, chestnut, species],
    uri_generator=UriPatternGenerator(pattern='urn:x-skosprovider:trees/%s'),
)

world = {
    'id': '1',
    'labels': [{'type': 'prefLabel', 'language': 'en', 'label': 'World'}],
    'narrower': [2, 3],
    'matches': {
        'close': ['urn:somethingelse:st1', 'urn:somethingelse:st2'],
        'exact': ['urn:something:thingy'],
        'related': ['urn:somethingelse:stuff'],
    },
}

geo = DictionaryProvider(
    {'id': 'GEOGRAPHY'},
    [
        world,
        {
            'id': 2,
            'labels': [{'type': 'prefLabel', 'language': 'en', 'label': 'Europe'}],
            'narrower': [4, 5],
            'broader': [1],
        },
        {
            'id': 3,
            'labels': [
                {'type': 'prefLabel', 'language': 'en', 'label': 'North-America'}
            ],
            'narrower': [6],
            'broader': [1],
        },
        {
            'id': 4,
            'labels': [{'type': 'prefLabel', 'language': 'en', 'label': 'Belgium'}],
            'narrower': [7, 8, 9],
            'broader': [2],
        },
        {
            'id': 5,
            'labels': [
                {'type': 'prefLabel', 'language': 'en', 'label': 'United Kingdom'}
            ],
            'broader': [2],
        },
        {
            'id': 6,
            'labels': [
                {
                    'type': 'prefLabel',
                    'language': 'en',
                    'label': 'United States of America',
                }
            ],
            'broader': [3],
        },
        {
            'id': 7,
            'labels': [{'type': 'prefLabel', 'language': 'en', 'label': 'Flanders'}],
            'broader': [4],
        },
        {
            'id': 8,
            'labels': [{'type': 'prefLabel', 'language': 'en', 'label': 'Brussels'}],
            'broader': [4],
        },
        {
            'id': 9,
            'labels': [{'type': 'prefLabel', 'language': 'en', 'label': 'Wallonie'}],
            'broader': [4],
        },
        {
            'id': '333',
            'type': 'collection',
            'labels': [
                {
                    'type': 'prefLabel',
                    'language': 'en',
                    'label': 'Places where dutch is spoken',
                }
            ],
            'members': ['4', '7', '8'],
        },
    ],
    uri_generator=UriPatternGenerator(pattern='urn:x-skosprovider:geo/%s'),
)



STIJLDATA = [
    {
        "broader": [],
        "id": 64,
        "labels": [
            {"label": "acheuleaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Acheulien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Genoemd naar de vindplaats Saint-Acheul in de buurt van Amiens"
                    " (Fr.). Het acheuleaan dekt het hele oudpaleolithicum. Deze"
                    " cultuur wordt gekenmerkt door een meer verfijnde afslagstijl"
                    " gericht op de vervaardiging van massieve werktuigen die aan beide"
                    " zijden (bifaciaal) bewerkt zijn. Het meest karakteristieke"
                    " bifaciaal werktuig is de vuistbijl. Het acheuleaan kent vooral"
                    " een verspreiding in westelijk Europa, ongeveer tot aan de Rijn."
                    " In de rest van Europa vindt men een minder verfijnde cultuur"
                    " terug, nl. het Clactoniaan."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/64",
    },
    {
        "broader": [],
        "id": 65,
        "labels": [
            {"label": "ahrensburgiaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Ahrensburgien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het ahrensburgiaan uit Noord-Europa (het laagland dat nu de"
                    " Noordzee is, van Duitsland tot Nederland en Zuidoost-Engeland),"
                    " genoemd naar de Duitse site van Ahrensburg-Stellmoor, vormde"
                    " zonder twijfel de voorbode van het mesolithicum. De"
                    " steenindustrie kenmerkt zich door een toenemende microlithisatie"
                    " die vooral in de pijlbewapening tot uiting komt. In het"
                    " ahrensburgiaan verschijnen immers de eerste microlieten. Het"
                    " belangrijkste gidsfossiel is de steelspits."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) Nederlandse"
                    " Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n3) Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van"
                    " Gijn A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/65",
    },
    {
        "broader": [],
        "id": 22,
        "labels": [{"label": "art deco", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "In de art deco wordt de geometrie tot ornament gemaakt."
                    " Aanvankelijk (proto-art deco) worden neoclassicistische gevels"
                    " onder Weense en Franse invloed voorzien van geometrisch"
                    " gestileerde ornamenten. Onder invloed van de Nederlandse"
                    " architectuur wordt een spel met baksteenverbanden en"
                    " baksteenkleuren ingevoerd. Het gehele gevelschema wordt"
                    " geometrisch, door geknikte gevelvormen, en vensters en deuren met"
                    " afgeschuinde bovenhoeken of in ruit- en trapeziumvorm. De"
                    " geometrische ornamentiek wordt aangevuld met smeedwerk en glas in"
                    " lood. De driehoek is een populair element. In de jaren 1930"
                    " evolueert de art deco. Elementen uit het modernisme en vooral uit"
                    " de scheepsarchitectuur worden op zeer decoratieve wijze in gevels"
                    " ge\xefntegreerd: vlaggenmasten, patrijspoortvensters,"
                    " gestroomlijnde vormen. (ca. 1910 tot Tweede Wereldoorlog)."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/22",
    },
    {
        "broader": [],
        "id": 30,
        "labels": [
            {"label": "art nouveau", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Jugendstil", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De art nouveau is een internationele beweging als reactie op de"
                    " neostijlen, maar met sterk lokale verschillen. In Belgi\xeb kent"
                    " de stijl twee stromingen, namelijk enerzijds de florale art"
                    " nouveau met Victor Horta als boegbeeld en anderzijds de"
                    " geometrische art nouveau be\xefnvloed door de Wiener Secession,"
                    " met Paul Hankar als boegbeeld. Het is een bouwstijl waarbij men"
                    " constructieve elementen toont, echter op zo'n manier dat zij ook"
                    " als versiering dienen. Deze stijl wordt gekenmerkt door het"
                    " gebruik van giet- en smeedijzer en glas, asymmetrie en een"
                    " vloeiend lijnenspel. De dieren- en plantenwereld was een bron van"
                    " inspiratie voor de ornamenten. Het is een totaalkunstvorm, die -"
                    " op zijn best - zowel het interieur als het exterieur tot in de"
                    " kleinste details omvat. (ca. 1890 tot WO I)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de"
                    " westerse architectuur- en bouwhistorie: bouwkundige termen,"
                    " Leiden, 2005."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/30",
    },
    {
        "broader": [],
        "id": 66,
        "labels": [
            {"label": "aurignaciaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Aurignacien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het aurignaciaan kenmerkt zich door zijn zeer grote verspreiding"
                    " en uniformiteit over zowat gans Europa en het Nabije Oosten. De"
                    " gidsfossielen zijn kielschrabbers, boogstekers en zgn. 'lamelles"
                    " Dufour'. Onder de benen artefacten vermelden we de assegaaien."
                    " Deze cultuur kan gedateerd worden van 35000 BP tot 29000 BP."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/66",
    },
    {
        "broader": [],
        "id": 93,
        "labels": [
            {"label": "bandkeramiek", "language": "nl-BE", "type": "prefLabel"},
            {"label": "LBK", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur dankt haar naam aan het aardewerk met ronde bodems"
                    " dat met typische banden is versierd. De BK-cultuur kan gedateerd"
                    " worden tussen 5500 en 5000/4900 v.Chr. De Bandkeramische"
                    " verspreiding vanuit Centraal-Europa in westelijke en"
                    " noordwestelijke richting gebeurde in 4 fasen: de oudste BK, de"
                    " oude BK, de midden BK en de recent BK-fase. Tegen circa 5250"
                    " v.Chr. heeft de Bandkeramiek ook Vlaanderen en zijn grootste"
                    " verspreiding bereikt. De meeste Bandkeramische sites zijn"
                    " ingeplant op loessgronden, die het best geschikt waren voor"
                    " primitieve landbouw. Het zijn meestal open dorpen, waar enkele"
                    " families samen hebben geleefd. Doorgaans bestaan ze uit enkele"
                    " huizen, die steeds noordwest-zuidoost geori\xebnteerd. De"
                    " precieze reden voor het plotse verdwijnen van de Bandkeramiek"
                    " rond 4900 v.Chr. is vooralsnog niet bekend."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/93",
    },
    {
        "broader": [],
        "id": 7,
        "labels": [{"label": "barok", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De barok is een bouwstijl die gekenmerkt wordt door volplastische"
                    " vormen, gebogen lijnen (concaaf-convex) en een contrast tussen"
                    " licht en donker, massa en leegte. Kenmerkend voor de barokke"
                    " gevels zijn de voluut- en klokgevels. Ook werd de kolossale orde"
                    " ingevoerd op de rijkversierde gevels. Voor de versiering vond de"
                    " barok haar inspiratie vaak in de oudheid, zoals de zuilenordes en"
                    " frontons. Deze worden aangevuld met voluten en vlampotten."
                    " (grosso modo 17de eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de"
                    " westerse architectuur- en bouwhistorie: bouwkundige termen,"
                    " Leiden, 2005; Nederlandse Art and Architecture Thesaurus"
                    " (www.aat-ned.nl)."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/7",
    },
    {
        "broader": [35],
        "id": 32,
        "labels": [
            {"label": "beaux-artsstijl", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De beaux-artsstijl is een architectuurstroming ontstaan uit het"
                    " onderwijs aan de Franse Ecoles des Beaux Arts. De stijl wordt"
                    " gekenmerkt door reminiscenties aan de grote Franse"
                    " architectuurstijlen uit de 18de eeuw: classicerende barok, rococo"
                    " en classicisme. Het gaat om rijk en zorgvuldig gedecoreerde"
                    " gevels in natuursteen en/of simili of in combinatie met baksteen."
                    " Borstweringen en poorten worden fraai uitgewerkt in smeedwerk."
                    " (laatste kwart 19de eeuw - ca. 1930)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [12],
        "sources": [
            {
                "citation": (
                    "www.irismonument.be; Nederlandse Art and Architecture Thesaurus"
                    " (www.aat-ned.nl)."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/32",
    },
    {
        "broader": [],
        "id": 28,
        "labels": [{"label": "brutalisme", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het brutalisme gaat terug op de late werken van Le Corbusier, met"
                    " zijn expressieve, ruw afgewerkte vormen. Typisch is het toepassen"
                    " van zichtbaar metselwerk en ruw, onversierd beton (zogenaamd"
                    " zichtbeton of b\xe9ton brut), waarbij de textuur van het"
                    " bekistingshout wordt gebruikt om het materiaal te vormen. (jaren"
                    " 1950 - 1970)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "VIOE, op basis van TRACHTENBERG M. &amp; HYMAN I. 2002:"
                    " Architecture from Prehistory to Postmodernity, New Jersey."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/28",
    },
    {
        "broader": [],
        "id": 8,
        "labels": [
            {"label": "classicerende barok", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Lodewijk-XIV-stijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De classicerende barok werd ontwikkeld in Frankrijk en sluit aan"
                    " bij de barok, maar laat zich sterker inspireren door de klassieke"
                    " vormentaal. De gebouwen hebben dikwijls nog een zware vormgeving"
                    " die aansluit bij de baroktraditie. Typische elementen zijn de"
                    " halsgevel, geflankeerd door vleugelstukken in de vorm van"
                    " voluten; een fronton op zware voluutconsoles; siervazen;"
                    " vlampotten (pot-\xe0-feu); bloemenslingers (guirlandes,"
                    " festoenen), balustrades en panelen met uitgeronde hoeken op de"
                    " borstwering van de vensters. Imitatiebanden leggen de nadruk op"
                    " de verschillende geledingen van de gevel.  (grosso modo eerste"
                    " helft 18de eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [12],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/8",
    },
    {
        "broader": [],
        "id": 10,
        "labels": [
            {"label": "classicisme", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Lodewijk XVI-stijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het classicisme is een strakke architectuur ge\xefnspireerd op de"
                    " bouwstijl van de klassieke oudheid, zoals de Griekse of Romeinse"
                    " tempelgevel met fronton en zuilenporticus. Men keerde terug naar"
                    " de symmetrie en de rechte lijnen. De spaarzame decoratie bestaat"
                    " onder meer uit: guirlandes of festoenen, consoles, urnen en"
                    " rozetten. Ook klassieke palmetten, meanders, kraal- en"
                    " eierlijsten worden aangetroffen. Deze stijl (ca. tweede helft"
                    " 18de eeuw) gaat in het eerste kwart van de 19de eeuw geleidelijk"
                    " over in het laatclassicisme."
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": "HTML",
                "note": (
                    "26/11/2014: aanpassing laatste zin door Leen Meganck, op basis van"
                    " discussie <a"
                    ' href="https://trac.onroerenderfgoed.be/oei/ticket/2181">https://trac.onroerenderfgoed.be/oei/ticket/2181</a>'
                ),
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "In de Databank Bouwkundig Erfgoed worden gebouwen in"
                    " laatclassicistische stijl ook opgenomen onder classicisme."
                ),
                "type": "note",
            },
        ],
        "related": [12],
        "sources": [
            {
                "citation": "KOCH W. 1988: De Europese bouwstijlen, Amsterdam.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/10",
    },
    {
        "broader": [],
        "id": 31,
        "labels": [
            {"label": "cottagestijl", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Normandische stijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De cottagestijl inspireert zich op de Engelse landelijke cottages."
                    " Het pittoreske effect van het exterieur werd onder meer bereikt"
                    " door het gebruik van traditionele materialen zoals hout, baksteen"
                    " of natuursteen, traditionele bouwtechnieken zoals vakwerkbouw en"
                    " een asymmetrische opbouw. Een onregelmatig grondplan in L-vorm of"
                    " met veel erkers en insprongen, vensters van diverse grootte en"
                    " een levendig spel van daken en schouwen zorgden voor een"
                    " gevarieerd exterieur van de woningen in cottagestijl.(laatste"
                    " kwart 19de en eerste helft 20ste eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/31",
    },
    {
        "broader": [],
        "id": 67,
        "labels": [
            {"label": "creswelliaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Creswellien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het creswelliaan is een uitgesproken Noord-Europese traditie"
                    " (zuidelijk UK). Gidsfossielen zijn de Creswell- en Cheddarspits."
                    " Deze traditie kan gedateerd worden van 12500 tot 12000 BP en is"
                    " gelijktijdig met het hamburgiaan. De aanwezigheid van deze"
                    " cultuur in Belgi\xeb is nog betwistbaar."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/67",
    },
    {
        "id": 61,
        "labels": [{"label": "culturen", "language": "nl-BE", "type": "prefLabel"}],
        "member_of": [],
        "members": [62, 63],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/61",
    },
    {
        "id": 63,
        "labels": [
            {
                "label": "culturen uit de metaaltijden",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [61],
        "members": [114, 115, 116, 117, 119, 120, 121],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/63",
    },
    {
        "id": 62,
        "labels": [
            {
                "label": "culturen uit de steentijd",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [61],
        "members": [
            64,
            65,
            66,
            67,
            68,
            69,
            82,
            87,
            88,
            89,
            91,
            93,
            95,
            97,
            98,
            100,
            102,
            104,
            106,
            108,
            109,
            110,
            112,
            113,
        ],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/62",
    },
    {
        "broader": [35],
        "id": 29,
        "labels": [
            {"label": "eclecticisme", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Rundbogenstil", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het eclecticisme is een bouwstijl waarbij de architect als het"
                    " ware gaat kiezen uit de catalogus van de gehele"
                    " architectuurgeschiedenis om elementen ervan te combineren tot een"
                    " nieuw geheel. De kunst bestond erin de diverse vormen,"
                    " technieken, constructieprincipes, architectuurregels,"
                    " verhoudingen, symbolen en sferen te laten samensmelten alsof ze"
                    " altijd op die manier hadden bestaan.(tweede helft 19de eeuw tot"
                    " WOI)"
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "In de Databank Bouwkundig Erfgoed wordt ook de Rundbogenstil"
                    " opgenomen bij eclecticisme."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "VIOE, op basis van Jos Vandenbreeden, Eclecticisme, in: Jos"
                    " Vandenbreeden, Fran\xe7oise Dierkens-Aubry, De 19de eeuw in"
                    " Belgi\xeb. Architectuur en Interieurs, Tielt, Lannoo, 1994,"
                    " p. 87."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/29",
    },
    {
        "broader": [],
        "id": 11,
        "labels": [{"label": "empire", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De empirestijl is in hoofdzaak een decoratieve stijl (meubels en"
                    " interieur), waarvan de architectuur motieven heeft overgenomen."
                    " Hij werd voor de Franse keizer Napoleon ontwikkeld door de"
                    " architecten Charles Percier en Fran\xe7ois Fontaine. Deze"
                    " bouwstijl heeft als basis de neoclassicistische bouwstijl, en"
                    " combineert deze met napoleontische motieven (zwaan, fasces,...)"
                    " en motieven die verwijzen naar de Griekse en Egyptische oudheid"
                    " zoals sfinxen, meanderfriezen, mercuriushoofden of palmetten."
                    " Kenmerkend voor de empire-gevels zijn het palladiaans venster, en"
                    " de rijen gekoppelde rondboogvensters met muurdammen uitgewerkt"
                    " als pilasters met lijstkapiteel. (ca. 1795 - ca. 1840)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [33, 36],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/11",
    },
    {
        "broader": [],
        "id": 68,
        "labels": [
            {"label": "enkelgrafcultuur", "language": "nl-BE", "type": "prefLabel"},
            {"label": "standvoetbekercultuur", "language": "nl-BE", "type": "altLabel"},
            {"label": "touwbekercultuur", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur komt op in Noord-Nederland, Scandinavi\xeb,"
                    " Duitsland, Polen, Oost-Frankrijk en Zwitserland rond 3000 v.Chr."
                    " De enkelgrafcultuur verschijnt dan. Het betreft een vooral"
                    " Noord-Europese cultuur, gekenmerkt o.a. door aardewerk dat"
                    " versierd is met touwindrukken (vandaar de alternatieve benaming"
                    " Touwbekercultuur) en een totaal nieuw grafritueel, nl."
                    " individuele in plaats van collectieve begraving. Men vindt ze"
                    " veel in graven van mannen, meestal samen met een strijdhamer."
                    " Deze gepolijste hardstenen bijlen hebben en centrale doorboring"
                    " en veelal een dubbele snede. Het graf ligt ook hier onder een"
                    " grafheuvel. De nadruk ligt hier op het individu, vooral de man."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9 &amp; Prof. J."
                    " Bourgeois) \n2) VIOE"
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/68",
    },
    {
        "broader": [23],
        "id": 24,
        "labels": [{"label": "expo-stijl", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De expo-stijl ontleent zijn naam aan de Wereldtentoonstelling in"
                    " Brussel in 1958 en straalt het optimisme en geloof in de toekomst"
                    " uit dat zo kenmerkend was voor de Expo. Dankzij het gebruik van"
                    " de hyperbolische parabolo\xefde, de betonnen"
                    " schaaldakconstructie, een voorkeur voor zwevende, hangende en"
                    " lichte constructies en contrasten in kleur- en materiaalkeuze,"
                    " zette men zich af tegen de architectuurtraditie. Er werd resoluut"
                    " gebruik gemaakt van moderne materialen, zoals beton, metaal en"
                    " grote glasvlakken, waarbij de dragende structuur werd benadrukt."
                    " De typische decoraties, zoals diagonalen, boemerang, V-vorm,"
                    " spits toelopende vormen, enz. werden gebruikt in zowel het"
                    " architecturale ontwerp als bij de uitwerking van de decoratieve"
                    " details."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "VIOE, op basis van PASAMONIK D. 1983: Expo '58 en de atoomstijl,"
                    " Kortrijk, en HESS A. 2004: Googie Redux. Ultramodern roadside"
                    " architecture, San Francisco."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/24",
    },
    {
        "broader": [],
        "id": 69,
        "labels": [
            {"label": "federmesser", "language": "nl-BE", "type": "prefLabel"},
            {"label": "aziliaan", "language": "nl-BE", "type": "altLabel"},
            {"label": "Azilien", "language": "nl-BE", "type": "altLabel"},
            {"label": "tjonger", "language": "nl-BE", "type": "altLabel"},
            {"label": "tjongeriaan", "language": "nl-BE", "type": "altLabel"},
            {"label": "tjongercultuur", "language": "nl-BE", "type": "altLabel"},
            {"label": "tjongertraditie", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De federmessercultuur sluit technologisch en typologisch zeer nauw"
                    " aan bij het magdaleniaan en het hamburgiaan. De debitagetechniek"
                    " is echter minder verzorgd. In de pijlbewapening komt een nieuw"
                    " spitstype op, nl. de Federmesser- of Tjongerspits. De cultuur kan"
                    " gerelateerd worden aan het finaalpaleolithicum."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/69",
    },
    {
        "broader": [],
        "id": 4,
        "labels": [{"label": "gotiek", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De gotiek is ontstaan dankzij een technisch-constructieve"
                    " vooruitgang als gevolg van een herverdeling van de krachten via"
                    " een skeletbouw en schoorwerk. Deze stijl wordt gekenmerkt door"
                    " haar verticaliteit, grote vensteropeningen, spitsbogen en"
                    " kruisribgewelven. (ca. 13de eeuw - begin 16de eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de"
                    " westerse architectuur- en bouwhistorie: bouwkundige termen,"
                    " Leiden, 2005."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/4",
    },
    {
        "broader": [],
        "id": 82,
        "labels": [
            {"label": "gravettiaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Gravettien", "language": "nl-BE", "type": "altLabel"},
            {"label": "p\xe9rigordiaan", "language": "nl-BE", "type": "altLabel"},
            {"label": "P\xe9rigordien", "language": "nl-BE", "type": "altLabel"},
            {"label": "perigordiaan", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De oudste vindplaatsen van het gravettiaan vinden we in"
                    " Centraal-Europa. Vermoedelijk verspreidde de cultuur zich van"
                    " daaruit over de rest van Europa, inclusief Noordwest-Europa. De"
                    " gidsfossiel is de zgn. Gravettespits en de Font-Robertspits."
                    " Onder de organische werktuigen vermelden we de 'b\xe2tons de"
                    " commondements' die waarschijnlijk gebruikt werden voor het"
                    " vervaardigen van assegaaien. Deze cultuur kan gedateerd worden"
                    " van 29000 tot 22000 BP. Perigordiaan is een verouderde term voor"
                    " deze cultuur."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/82",
    },
    {
        "broader": [],
        "id": 87,
        "labels": [
            {"label": "groupe de Blicquy", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Regionale variant van Villeneuve/Saint-Germain (Noord-Frankrijk)"
                    " in Belgi\xeb. Nederzettingen van de Blicquy-groep worden op"
                    " dezelfde plaatsen teruggevonden als LBK-nederzettingen, nl. aan"
                    " de bovenloop van de Dender in Henegouwen en in het LBK-gebied in"
                    " Haspengouw. Wordt gekenmerkt door typisch Blicquy-aardewerk. Deze"
                    " groep overlapt mogelijk deels met het laatste deel van de LBK en"
                    " loopt hierna verder."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "Lanting J.N. &amp; Van der Plicht J. 2002, De C14-chronologie van"
                    " de Nederlandse pre- en protohistorie. III: Neolithicum, in:"
                    " Palaeohistoria: Acta et communicationes Instituti"
                    " Bioarchaeologici Universitatis Groniganae 41/42, pp. 1-111."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/87",
    },
    {
        "broader": [],
        "id": 114,
        "labels": [{"label": "Halstatt", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [63],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Verwijst naar een periode en cultuur in de late bronstijd en de"
                    " vroege ijzertijd, van circa 1100 tot circa 450 v. Chr."
                    " aangetroffen in Centraal- en West-Europa, en genoemd naar een"
                    " begraafplaats en een zoutmijn in Halstatt (Oostenrijk)."
                    " Begrafenispraktijken en artistieke stijlen verschilden per tijd"
                    " en per plaats, maar over het algemeen wordt de cultuur gekenmerkt"
                    " door de opkomst van handel met omliggende gebieden, door"
                    " kunstvoorwerpen met symmetrische ontwerpen, geometrische"
                    " versieringen, vogel- en plantenmotieven, en door de invloed van"
                    " Italiaanse en mogelijk Griekse kunst."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/114",
    },
    {
        "broader": [],
        "id": 88,
        "labels": [
            {"label": "hamburgiaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Hamburgien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur zou ontstaan zijn uit het magdaleniaan. Het is een"
                    " uitgesproken Noord-Europese traditie (noordelijk deel van"
                    " Nederland, Duitsland, Polen en zuidelijk Scandinavi\xeb)."
                    " Gidsfossielen zijn de Hamburg- en Haveltespits. Deze traditie kan"
                    " gedateerd worden van 12500 tot 12000 BP en is gelijktijdig met"
                    " het Creswelliaan."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) Louwe"
                    " Kooijmans L., van den Broecke P.W., Fokkens H. en van Gijn A."
                    " (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/88",
    },
    {
        "broader": [],
        "id": 89,
        "labels": [
            {"label": "hazendonkgroep", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze groep kan gedateerd worden van 3900 tot 3400 v.Chr. en komt"
                    " voor in Zuid-Nederland en Belgi\xeb. Het kenmerkt zich door een"
                    " geheel eigen aardewerkrepertoire."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "Deeben J. e.a. (red.) 2005, De Steentijd van Nederland, Zutphen."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/89",
    },
    {
        "broader": [],
        "id": 27,
        "labels": [{"label": "high tech", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De high tech architectuur bouwt verder op het modernistische idee"
                    " dat een gebouw de veruitwendiging is van een bouwprogramma. In de"
                    " high tech architectuur worden de constructie (vaak een stalen"
                    " skeletstructuur) en de technische installaties heel expliciet"
                    " getoond, en wordt het gebouw bijna een ode aan de technologie en"
                    " de ingenieurskunst. Een bekend voorbeeld van deze bouwstijl is"
                    " het Centre Pompidou te Parijs, van Richard Rogers en Renzo Piano"
                    " uit 1976. (jaren 1980)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "VIOE, op basis van TRACHTENBERG M. &amp; HYMAN I. 2002:"
                    " Architecture from Prehistory to Postmodernity, New Jersey."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/27",
    },
    {
        "broader": [],
        "id": 115,
        "labels": [
            {"label": "Hilversum-cultuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [63],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "In onze gewesten, waar geen ertsen aanwezig zijn, treft men minder"
                    " rijke culturen aan, zoals de Hilversum-cultuur. Deze kan"
                    " geplaatst worden in de vroege en midden-bronstijd. Kenmerkend"
                    " voor deze cultuur is het grofgemagerd Hilversumaardewerk, de"
                    " grote ringwalheuvels en de heuvels met paalkrans. Het gaat om een"
                    " lokaal ontwikkelde archeologische cultuur met een open begrenzing"
                    " met zijn kerngebied in Zuid-Nederland en Vlaanderen. De grote"
                    " ringwalheuvels kennen een wijde verspreiding (Zuid-Nederland,"
                    " Belgi\xeb, Noord-Frankrijk en Zuid-Engeland). Heuvels met"
                    " paalkrans kennen een beperktere verspreiding (zuidoost-Brabant en"
                    " de Belgische Kempen). De minder rijke graven in het Atlantisch"
                    " complex zijn meestal relatief klein (enkele eenheden, tot"
                    " maximaal een 10 of 20-tal graven), die veelal slechts gedurende"
                    " een korte periode zijn gebruikt. Men schat de"
                    " \u2018levensduur\u2019 van een dergelijk grafveld op \xe9\xe9n"
                    " generatie. In grote ge\xefsloeerde grafheuvels komen ook"
                    " secundaire bijzettingen voor. De nederzettingen van de"
                    " Hilversumcultuur zijn steeds open nederzettingen, d.i. zonder"
                    " versterkingen, waar een tot vier huizen samen voorkomen, naast"
                    " enkele bijgebouwen. Het huisplattegrond in de (late)"
                    " Hilversumcultuur is typerend: het betreft een langwerpig gebouw"
                    " (tot 25m lengte) met meestal absidiaal afgeronde korte zijden;"
                    " het huis is drieschepig en vertoont duidelijke onderverdelingen,"
                    " waarin verschillende functies (schuur, stal en woongedeelte)"
                    " kunnen worden onderscheiden. Men noemt ze ook woonstalhuizen. Het"
                    " Hilversumaardewerk evolueert van een biconische naar een"
                    " emmervormige vorm, zowel versierd (op kraag/rand met"
                    " touw/nagelindrukken) als onversierd. Men kan de Hilversumcultuur"
                    " dateren tussen 1775 en 1575 v.Chr."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Theunissen E.M. 1999, Midden-Bronstijdsamenlevingen in het"
                    " Zuiden van de Lage Landen: een evaluatie van het begrip"
                    " Hilversum-cultuur, Proefschrift ter verkrijgen van de graad van"
                    " Doctor, Universiteit Leiden. \n2) cursusmateriaal UGent (Prof. J."
                    " Bourgeois) \n3) VIOE"
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/115",
    },
    {
        "broader": [],
        "id": 123,
        "labels": [
            {
                "label": "integratiearchitectuur",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Integratiearchitectuur omvat een veelal kleinschalige nieuwbouw of"
                    " verbouwing die zich qua volumes, structuur en vaak ook qua"
                    " materiaal inschrijft in de omgeving, maar die eigentijds is van"
                    " vormgeving (circa 1975-1990)."
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "19/07/2016: toegevoegd voor project sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "CONSTANDT L. 1988: Stenen herleven. 111 jaar kunstige"
                    " herstellingen in Brugge, Brugge, 94."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/123",
    },
    {
        "broader": [],
        "id": 91,
        "labels": [
            {"label": "klokbekercultuur", "language": "nl-BE", "type": "prefLabel"},
            {"label": "KB", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur heeft zijn naam te danken aan het typische aardewerk"
                    " dat op de kop geplaatst lijkt op een klepelklok. De"
                    " klokbekercultuur heeft zich verspreid over grote delen van Europa"
                    " en kan chronologisch gesitueerd worden tussen 2400 en 1900 v.Chr."
                    " De cultuur is waarschijnlijk oorspronkelijk afkomstig uit Spanje"
                    " en heeft zich verspreid over Centraal- en West-Europa, daarbij de"
                    " techniek van het werken met brons naar de Britse eilanden"
                    " brengend. De cultuur wordt gekenmerkt door aardewerk, een"
                    " voorkeur voor individuele graven, snelle expansie op zoek naar"
                    " koper en goud, het ontstaan van talrijke wapens, waaronder bogen,"
                    " koperen speerpunten, platte, getande dolken en opvallende"
                    " gebogen, rechthoekige polsbeschermers. De klokbekercultuur moet"
                    " dus eerder beschouwd worden als een typische vorm van uiting van"
                    " elitevorming."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Deeben J. e.a. (red.) 2005, De Steentijd van Nederland,"
                    " Zutphen.  2) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/91",
    },
    {
        "broader": [],
        "id": 116,
        "labels": [{"label": "La T\xe8ne", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [63],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Verwijst naar een fase en cultuur van de Europese Kelten in de"
                    " late ijzertijd, genoemd naar de archeologische vindplaats La"
                    " T\xe8ne, of De Ondiepe Wateren, bij het Meer van Neuch\xe2tel in"
                    " Zwitserland. De fase begon in het midden van de 5de eeuw v. Chr."
                    " en de cultuur verspreidde zich over Noord-Europa en de Britse"
                    " Eilanden, om ten slotte halverwege de 1ste eeuw v. Chr. te"
                    " verdwijnen. La T\xe8ne kenmerkt zich door Griekse en Etruskische"
                    " invloeden op de traditionele Keltische cultuur en door de sterke"
                    " geografische verspreiding van de Kelten."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/116",
    },
    {
        "broader": [12],
        "id": 56,
        "labels": [
            {"label": "Louis-Philippestijl", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De Louis-Philippestijl is een variant op het neoclassicisme,"
                    " ontwikkeld in Frankrijk onder burgerkoning Louis-Philippe, en"
                    " hier toegepast tijdens de jaren 1850. Typisch zijn de"
                    " gevelopstanden met een plastische vormgeving en een uitbundig"
                    " stucdecor, ge\xefnspireerd op de vloeiende lijnvoering van het"
                    " rococo. Vaak voorkomende decoratieve elementen  zijn balkons met"
                    " geajoureerde borstwering en rijk versierde voluutconsoles, en"
                    " sluitstenen met een decor van maskerkoppen en/of rankwerk."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/56",
    },
    {
        "broader": [],
        "id": 95,
        "labels": [
            {"label": "magdaleniaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Magdalenien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Genoemd naar de Franse vindplaats La Madeleine nabij Tursac in"
                    " Dordogne. Deze cultuur ontwikkelt zich in Zuidwest-Europa en zal"
                    " zich geleidelijk ook verspreiden over Centraal- en West-Europa en"
                    " kan gedateerd worden tussen 17000 en 14000 BP"
                    " (jongpaleolithicum). De cultuur kenmerkt zich door het ontstaan"
                    " van permanente of seizoensnederzettingen, het gebruik van een"
                    " grote verscheidenheid aan planten en dieren, onder andere door"
                    " het gebruik van strikken en vallen, en de ingenieuze"
                    " vervaardiging van werktuigen, decoratieve vormen en"
                    " kunstvoorwerpen. Gereedschappen werden gemaakt van bot en steen"
                    " en hebben geometrisch gevormde snijbladen. Er zijn ook andere"
                    " werktuigen van bot en geweien, graveerijzers, naalden, schrapers,"
                    " boren, snijbladen met achterkanten, harpoenen en bladvormige"
                    " punten voor projectielen. De artistieke productie bestond uit"
                    " monumentale inscripties en schilderingen in grotten, bewerken van"
                    " benen werktuigen, beeldhouwwerk en juwelen."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) Nederlandse"
                    " Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n3) VIOE"
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/95",
    },
    {
        "broader": [],
        "id": 97,
        "labels": [
            {"label": "michelsbergcultuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "In de 2de fase van het middenneolithicum verschijnt in de regio"
                    " van West- en Zuid-Duitsland, Belgi\xeb en Noord-Nederland de"
                    " michelsbergcultuur die men kan dateren tussen 4400 en 3500 v.Chr."
                    " De cultuur komt voor in nagenoeg heel Vlaanderen, in"
                    " tegenstelling tot de Bandkeramiek waarvan de verspreiding zich"
                    " beperkte tot de leemstreek. Zeer typisch voor de"
                    " Michelsbergcultuur zijn aardwerken of enclosures, grote"
                    " structuren bestaande uit \xe9\xe9n of meerdere grote grachten en"
                    " wallen die bijna steeds een hoge plek in het landschap afsluiten."
                    " Typische lithische werktuigen zijn grote, massieve eindschrabbers"
                    " op afslag (hoefschrabbers) en afslagbijlen. Naast hardstenen"
                    " bijlen worden nu ook gepolijste bijlen uit vuursteen vervaardigd."
                    " Het aardewerk is handgevormd en doorgaans gemagerd met grit en"
                    " plantaardig materiaal. De meeste potten zijn onversierd."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/97",
    },
    {
        "broader": [],
        "id": 98,
        "labels": [
            {"label": "micoquiaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Micoquien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het micoquiaan kenmerkt zich door asymmetrische vuistbijlvormen en"
                    " het gebruik van de Levalloistechniek. Het kan deels gelijktijdig"
                    " met het mousteriaan geplaatst worden (middenpaleolithicum)."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Cromb\xe9 P. &amp; Van Der Haeghen G. 1994, Twee"
                    " midden-paleolithische vindplaatsen te Aalter (O.-Vl.), in: P."
                    " Cromb\xe9 &amp; G. Van Der Haeghen (eds.), Het"
                    " midden-paleolithicum in Noordwestelijk Belgi\xeb, pp. 49-95. 2)"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/.">https://www.onderzoeksbalans.be/.</a>'
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/98",
    },
    {
        "broader": [],
        "id": 23,
        "labels": [
            {"label": "modernisme", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Nieuwe Zakelijkheid", "language": "nl-BE", "type": "altLabel"},
            {"label": "Internationale Stijl", "language": "nl-BE", "type": "altLabel"},
            {"label": "functionalisme", "language": "nl-BE", "type": "altLabel"},
            {"label": "pakketbootstijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [24],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Modernisme wordt in deze databank gehanteerd voor alle"
                    " architectuur die getuigt van een streven naar vernieuwing door"
                    " een versobering van\n de vormentaal. De meest pure vorm van"
                    " modernisme, vaak benoemd als de internationale stijl of"
                    " functionalisme, wordt gekenmerkt door een rationeel grondplan,"
                    " eenvoudige geometrische vormen, dragende (beton)skeletten met"
                    " platte daken, lichte scheidingswanden en het gebruik van moderne"
                    " materialen.\n De meeste gebouwen bereiken echter niet het pure"
                    " van de internationale stijl, maar getuigen niettemin van een"
                    " streven naar verzakelijking. Zij zijn doorgaans uitgewerkt met"
                    " egale bakstenen parementen, met een bescheiden volumewerking en"
                    " een sterk gereduceerde decoratie. (jaren 1920 tot jaren 1960)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "VIOE, op basis van HASLINGHUIS E.J. &amp; JANSE H. 2005:"
                    " Verklarend woordenboek van de westerse architectuur- en"
                    " bouwhistorie: bouwkundige termen, Leiden."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/23",
    },
    {
        "broader": [],
        "id": 100,
        "labels": [
            {"label": "mousteriaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Mousterien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Verwijst naar de periode en cultuur waarin specifieke"
                    " gereedschappen tot ontwikkeling komen in Europa, het"
                    " Midden-Oosten en Afrika, vanaf 250.000 jaar geleden. De periode"
                    " is genoemd naar de schuilgrotten bij Le Moustier in het"
                    " zuidwesten van Frankrijk. De cultuur wordt traditioneel in"
                    " verband gebracht met Neanderthalers in Europa en hun tijdgenoten"
                    " in Afrika. Het kenmerkt zich door de expansie van volkeren naar"
                    " nieuwe gebieden en aanpassingen aan nieuwe omgevingen, zoals"
                    " diversificatie en specialisatie van stenen werktuigen, vakkundig"
                    " en selectief jagen en doelbewust begraven en door het voorkomen"
                    " van de Levalloistechniek bij steenbewerking. Kleine vuistbijlen"
                    " en unifaciaal bewerkte spitsen zijn kenmerkende objecten voor"
                    " deze cultuur."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Deeben J. e.a. (red.) 2005, De Steentijd van Nederland,"
                    " Zutphen."
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/100",
    },
    {
        "broader": [],
        "id": 117,
        "labels": [
            {
                "label": "Nederrijnse grafheuvelcultuur",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {
                "label": "Niederrheinische grabh\xfcgelkultur",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [63],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De Nederrijnse grafheuvelcultuur wordt gekenmerkt door de"
                    " introductie van een nieuw begrafenisritueel (urnenvelden,"
                    " crematies, nieuwe graftypes (long barrows)), een nieuw"
                    " aardewerkrepertoire, de intensificatie van de bronscirculatie"
                    " door participatie in Atlantische en Centraal-Europese"
                    " uitwisselingsnetwerken en een geavanceerder landbouwsysteem"
                    " (celtic fields). De Nederrijnse bevolking vertoont in"
                    " materi\xeble cultuur in deze periode een hoge graad van autonomie"
                    " ten opzichte van de Centraal-Europese urnenveldencultuur waarmee"
                    " het chronologisch gelijktijdig verloopt. Dit idee van een"
                    " losstaande culturele identiteit wordt uitgedrukt met de term"
                    " 'Nederrijnse grafheuvelcultuur'. Het is een meer westelijke"
                    " variant van de Urnenveldencultuur."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Roymans N. &amp; Kortlang F. 1999, Urnfield symbolism,"
                    " ancestors and the land in the Lower Rhine Region, in: F. Theuws"
                    " &amp; N. Roymans (eds.), Land and ancestors: cultural dynamics in"
                    " the Urnfield Period and the Middle Ages in the Southern"
                    " Netherlands, Amsterdam Archaeological Studies 4, pp. 33-63. \n2)"
                    " VIOE"
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/117",
    },
    {
        "broader": [35],
        "id": 16,
        "labels": [
            {"label": "neobarok", "language": "nl-BE", "type": "prefLabel"},
            {
                "label": "neo-Lodewijk-XIV-stijl",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neobarok inspireert zich op de barokke architectuur.(ca. 1840"
                    " tot het interbellum)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/16",
    },
    {
        "broader": [35],
        "id": 18,
        "labels": [
            {"label": "neobyzantijns", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neobyzantijnse bouwstijl inspireert zich op de architectuur van"
                    " het Byzantijnse rijk, met onder meer de centraalbouw, het"
                    " koepeldak, een veelvuldig gebruik van rondbogen en bepaalde"
                    " decoratieve elementen zoals moza\xefeken met vergulde"
                    " achtergronden. (19de eeuw en eerste kwart 20ste eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "www.irismonument.be", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/18",
    },
    {
        "broader": [35],
        "id": 12,
        "labels": [
            {"label": "neoclassicisme", "language": "nl-BE", "type": "prefLabel"},
            {
                "label": "neo-Lodewijk XVI-stijl",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [36, 56],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het neoclassicisme inspireert zich op de classicistische"
                    " architectuur met ornamenten zoals ovale medaillons,"
                    " laurierguirlandes, voluutconsoles, enz. Deze stroming heeft net"
                    " zoals het classicisme een voorliefde voor orde en symmetrie, maar"
                    " gaat vrijer om met de classicistische ornamentiek. De gevels zijn"
                    " vaak, maar niet altijd, bepleisterd.(tweede helft 19de eeuw en"
                    " eerste kwart 20ste eeuw)"
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De Louis-Philippestijl is in de Databank Bouwkundig Erfgoed"
                    " opgenomen onder neoclassicisme."
                ),
                "type": "note",
            },
        ],
        "related": [8, 10, 32],
        "sources": [{"citation": "www.irismonument.be", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/12",
    },
    {
        "broader": [35],
        "id": 34,
        "labels": [
            {"label": "neo-Egyptisch", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neo-Egyptische bouwstijl inspireert zich op de architectuur uit"
                    " de Egyptische oudheid met onder meer bundelzuilen met papyrus- en"
                    " palmenkapitelen, de holgebogen kroonlijst en de voor deze antieke"
                    " cultuur typerende versieringen. (19de eeuw en eerste kwart 20ste"
                    " eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "www.irismonument.be", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/34",
    },
    {
        "broader": [35],
        "id": 33,
        "labels": [{"label": "neo-empire", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neo-empire inspireert zich op de empire-architectuur. (tweede"
                    " helft 19de eeuw en eerste kwart 20ste eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [11, 36],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/33",
    },
    {
        "broader": [35],
        "id": 13,
        "labels": [
            {"label": "neogotiek", "language": "nl-BE", "type": "prefLabel"},
            {"label": "neotudorstijl", "language": "nl-BE", "type": "altLabel"},
            {"label": "troubadourstijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neogotiek inspireert zich op de gotische architectuur met o.m."
                    " spitsbogen, verticalisme, puntgevels, erkers, enz.(ca.1820 tot"
                    " WOII)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/13",
    },
    {
        "broader": [35],
        "id": 17,
        "labels": [{"label": "neomoors", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neomoorse bouwstijl inspireert zich op de Maghrebijnse,"
                    " Arabische, Osmaanse en Moorse architectuur. Kenmerkend voor deze"
                    " stijl zijn onder meer minaretten, koepels, hoefijzerbogen en"
                    " polychromie in de onderbouw. (19de eeuw en eerste kwart 20ste"
                    " eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "VIOE, op basis van Jos Vandenbreeden, Fran\xe7oise Dierkens-Aubry,"
                    " De 19de eeuw in Belgi\xeb. Architectuur en Interieurs, Tielt,"
                    " Lannoo, 1994, p.165."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/17",
    },
    {
        "broader": [35],
        "id": 122,
        "labels": [
            {"label": "neorenaissance", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300021464"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neorenaissancestijl is een architectuurstijl (circa 1860-1914)"
                    " die zich inspireert op de renaissance, een kunststroming ontstaan"
                    " in het Itali\xeb van de 15de eeuw en die er onder meer op gericht"
                    " was de bouwkunst van de Grieks-Romeinse oudheid te doen herleven."
                    " Stijlkenmerken zijn een symmetrische opbouw van de gevel,"
                    " frontonbekroningen, zuilen en pilasters enzoverder. In Vlaanderen"
                    " is vooral de neo-Vlaamserenaissance-stijl populair."
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "26/02/2015: term toegevoegd; SN wordt aangeleverd tegen de"
                    " zomer.\n06/05/2015: SN aangeleverd door Elise en toegevoegd."
                ),
                "type": "historyNote",
            },
        ],
        "related": [14],
        "sources": [{"citation": "www.irismonument.be", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/122",
    },
    {
        "broader": [35],
        "id": 19,
        "labels": [
            {"label": "neorococo", "language": "nl-BE", "type": "prefLabel"},
            {"label": "neo-Lodewijk-XV-stijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het neorococo inspireert zich op het rococo.(ca. 1860 tot WOII)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/19",
    },
    {
        "broader": [35],
        "id": 15,
        "labels": [{"label": "neoromaans", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neoromaanse bouwstijl inspireert zich op de romaanse"
                    " architectuur de rondbogen als centraal motief. (19de eeuw tot ca."
                    " WO II)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/15",
    },
    {
        "broader": [],
        "id": 35,
        "labels": [{"label": "neostijl", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [12, 13, 14, 15, 16, 17, 18, 19, 29, 32, 33, 34, 122],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Neostijl is een verzamelnaam voor stijlen vanaf de 19de eeuw die"
                    " kenmerken van een vroegere stijl opnieuw gebruiken. (19de eeuw en"
                    " eerste helft 20ste eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de"
                    " westerse architectuur- en bouwhistorie: bouwkundige termen,"
                    " Leiden, 2005."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/35",
    },
    {
        "broader": [],
        "id": 21,
        "labels": [
            {"label": "neotraditioneel", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neotraditionele bouwstijl inspireert zich op de traditionele"
                    " architectuur, die men eerder vrij gaat incorporeren in een meer"
                    " eigentijdse vormgeving, met eigentijdse materialen en technieken."
                    " (19de eeuw en 20ste eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/21",
    },
    {
        "broader": [35],
        "id": 14,
        "labels": [
            {
                "label": "neo-Vlaamserenaissance-stijl",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De neo-Vlaamse-renaissance inspireert zich op de"
                    " renaissance-architectuur en verwerkt elementen gaande van de"
                    " Vredeman-de-Vriesstijl tot de barok: trapgevels, kruisvensters,"
                    " torentjes, erkers, voluten, obelisken, etc. Typisch is het"
                    ' polychroom materiaalgebruik en de toepassing van "speklagen"'
                    " (=afwisseling baksteen en natuursteen). (circa 1870 tot Eerste"
                    " Wereldoorlog)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [122],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/14",
    },
    {
        "broader": [],
        "id": 25,
        "labels": [
            {
                "label": "organische architectuur",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Bij de organische architectuur bepaalt de functie de vorm. Men"
                    " gaat ervan uit dat de architectuur een invloed uitoefent op de"
                    " gebruiker. Met schuine plafonds, ronde hoeken en een beweeglijke"
                    " vormgeving wil men een aangename omgeving cre\xebren voor de"
                    " gebruiker."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/25",
    },
    {
        "broader": [],
        "id": 119,
        "labels": [
            {"label": "Plainseaucultuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [63],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze omschrijving verwijst meer naar de bloeiende bronsindustrie"
                    " in de streek van Amiens en Picardi\xeb dan naar een echte"
                    " cultuur, vermits er geen woningen of necropolen mee in verband"
                    " kunnen worden gebracht. Voorwerpen van het Plainseau-type werden"
                    " ge\xebxporteerd tot in Zuid-Engeland, Nederland en Belgi\xeb."
                    " Naast enkele ge\xefsoleerde vondsten in de Maas- en de"
                    " Scheldevallei, werden kleinere depots opgegraven in onder meer"
                    " Hoogstraten, Antwerpen, Lanaken en Eprave."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) De Plainseau-cultuur <a"
                    ' href="https://www.patrimoine-mobilier.be/patrimoine/additional_info.aspx?id=214684&amp;LangType=2067">https://www.patrimoine-mobilier.be/patrimoine/additional_info.aspx?id=214684&amp;LangType=2067</a>'
                    " \n2) VIOE"
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/119",
    },
    {
        "broader": [],
        "id": 26,
        "labels": [
            {"label": "postmodernisme", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het postmodernisme zet zich af tegen het functionalisme en de"
                    " soberheid van het modernisme. Het ornament wordt opnieuw in eer"
                    " hersteld en moet het gebouw betekenis verlenen. Vormelementen uit"
                    " het verleden (classicisme, art deco, enz) worden op eigentijdse"
                    " wijze en vaak met een ondertoon van humor als citaten toegepast."
                    " (jaren 1970 en 1980)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "VIOE, o.m. op basis van www.irismonument.be en TRACHTENBERG M."
                    " &amp; HYMAN I. 2002: Architecture from Prehistory to"
                    " Postmodernity, New Jersey."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/26",
    },
    {
        "broader": [],
        "id": 20,
        "labels": [{"label": "regionalisme", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het regionalisme inspireert zich op de regionale bouwstijl, met"
                    " zijn lokale, regiogebonden materialen, technieken en"
                    " vormkenmerken. Vanuit deze elementen cre\xebert men een nieuwe"
                    " architectuur. Het regionalisme was de dominerende stijl tijdens"
                    " de wederopbouw na WO I. (laatste kwart 19de eeuw en eerste helft"
                    " 20ste eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/20",
    },
    {
        "broader": [],
        "id": 5,
        "labels": [{"label": "renaissance", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De renaissancebouwstijl poogde de vormentaal van de antieke"
                    " oudheid opnieuw toe te passen. Vaak paste men elementen uit de"
                    " Italiaanse renaissance toe op de traditionele bak- en"
                    " zandsteenstijl. De typische renaissancegevel heeft een in- en"
                    " uitgezwenkte top, bekroond met een (buiten proportie) klein"
                    " fronton. Lijsten delen de geveltop horizontaal op. Centraal in de"
                    " geveltop is meestal een oculus aangebracht. Als materiaal wordt"
                    " baksteen gebruikt, in combinatie met witte natuursteen"
                    " (Balegemse) voor de constructieve details en de ornamentiek. In"
                    " de renaissance zijn de kruisvensters courant, bovenaan ingevuld"
                    " met vast glas-in-lood, onderaan afgesloten door openslaande"
                    " raamvleugels met luikjes. Veel voorkomende ornamenten in de"
                    " renaissance zijn de versierde gevelankers, zuilen en pilasters"
                    " volgens de klassieke orde, frontons, eierlijsten, obelisken,"
                    " saters en mascarons. (grosso modo de 16de eeuw)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/5",
    },
    {
        "broader": [],
        "id": 120,
        "labels": [
            {
                "label": "Rhin-Suisse-France Oriental",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [63],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De Rhin-Suisse-France ori\xebntale cultuur wordt gekenmerkt door"
                    " typische urnenvelden, een bloeiende metaalproductie en o. a."
                    " nederzettingen aan oevers van meren en rivieren (paaldorpen)."
                    " Meer oostelijke variant van de Urnenveldencultuur."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. J. Bourgeois) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/120",
    },
    {
        "broader": [],
        "id": 102,
        "labels": [
            {"label": "Rijnbekkengroep", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Rheinbasin-kreis", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Vanaf het vroegmesolithicum treedt een regionalisatie op in de"
                    " materi\xeble cultuur. Men kan in Zuid-Nederland, Belgi\xeb en een"
                    " deel van Frankrijk de Rijnbekkengroep (Rheinbassin-kreis)"
                    " onderscheiden. In Noord-Nederland krijgt men dan de"
                    " Noordwest-groep (Nordwest-kreis). Een toename van het gebruik van"
                    " het aantal spitstypen en een toename van het gebruik van"
                    " Wommersomkwartsiet plus de toepassing van oppervlakte-retouches"
                    " zijn kenmerkend voor deze periode. Sauveterre-spitsen,"
                    " bladspitsen en feuilles de gui doen hun intrede."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Lanting J.N. &amp; Van der Plicht J. 1998, De C14-chronologie"
                    " van de Nederlandse pre- en protohistorie. II: Mesolithicum, in:"
                    " Palaeohistoria: Acta et communicationes Instituti"
                    " Bio-archaeologici Universitatis Groninganae 39/40, pp. 99-162."
                    " \n2) Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van"
                    " Gijn A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/102",
    },
    {
        "broader": [],
        "id": 9,
        "labels": [
            {"label": "rococo", "language": "nl-BE", "type": "prefLabel"},
            {"label": "r\xe9gence", "language": "nl-BE", "type": "altLabel"},
            {"label": "Lodewijk-XV-stijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Het rococo is in hoofdzaak een decoratieve stijl (meubels en"
                    " interieur), die gekenmerkt wordt door haar speelsheid, lichte"
                    " kleuren en asymmetrische lijnenspel. Ze dankt haar naam aan de"
                    " rocaille, het asymmetrische schelpmotief, dat veelvuldig gebruikt"
                    " wordt als decoratie. (midden 18de eeuw)"
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "In de Databank Bouwkundig Erfgoed wordt ook r\xe9gence opgenomen"
                    " bij rococo."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de"
                    " westerse architectuur- en bouwhistorie: bouwkundige termen,"
                    " Leiden, 2005; KOCH W. 1988: De Europese bouwstijlen, Amsterdam."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/9",
    },
    {
        "broader": [],
        "id": 3,
        "labels": [{"label": "romaans", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De romaanse bouwstijl wordt gekenmerkt door massieve stenen muren"
                    " met kleine gevelopeningen, doorgaans met rondboog en soms gedeeld"
                    " door middenzuiltjes. De overdekking gebeurde met een vlak houten"
                    " gewelf, of - minder courant - met stenen ton-, kruis- en"
                    " koepelgewelven. De decoratieve afwerking wordt gekarakteriseerd"
                    " door rondboogfriezen, rondboognissen en lisenen. (ca. 10de eeuw"
                    " tot 1200)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de"
                    " westerse architectuur- en bouwhistorie: bouwkundige termen,"
                    " Leiden, 2005."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/3",
    },
    {
        "broader": [],
        "id": 104,
        "labels": [
            {"label": "r\xf6ssencultuur", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Roessener", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur komt tot uiting in westelijk Duitsland en de"
                    " oostelijke Benelux en kan gedateerd worden tussen 5000 en"
                    " 4400/4300 v.Chr. Ze ontwikkelde zich in het Rijnland vanuit de"
                    " Bandkeramische cultuur. De nederzettingen uit de r\xf6ssencultuur"
                    " zijn versterkt en de gebouwen hebben een trapezo\xefdale"
                    " plattegrond. In Vlaanderen zijn geen sites van deze cultuur"
                    " gekend, wel is deze cultuur vertegenwoordigd door een aantal"
                    " losse vondsten van Breitkeile (soort hamer/bijl)."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/104",
    },
    {
        "broader": [12],
        "id": 36,
        "labels": [
            {"label": "second empire", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De second-empirestijl is een variant op het neoclassicisme,"
                    " ontwikkeld in Frankrijk onder Napoleon III.\n Typisch zijn de"
                    " zeer zware, exuberante vormen, en de mansardedaken. De gevel"
                    " krijgt een sterk bewogen en plastisch karakter. De second"
                    " empirestijl vertoont een voorkeur voor een uitbundige,"
                    " sculpturale decoratie. (ca. 1850-1870)"
                ),
                "type": "scopeNote",
            }
        ],
        "related": [11, 33],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/36",
    },
    {
        "broader": [],
        "id": 106,
        "labels": [
            {"label": "Seine-Oise-Marne", "language": "nl-BE", "type": "prefLabel"},
            {"label": "SOM", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur komt voor in noordelijk Frankrijk en zuidelijk"
                    " Belgi\xeb en kan gesitueerd worden in het laatneolithicum."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/106",
    },
    {
        "broader": [],
        "id": 108,
        "labels": [{"label": "steingroep", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze groep is onderdeel van het cultuurcomplex dat geografisch"
                    " gezien tussen de trechterbekercultuur in het Noorden en de"
                    " Seine-Oise-Marne-cultuur (waarmee het grote overeenkomsten kent)"
                    " in het Zuiden ligt. De steingroep kan gedateerd worden tussen"
                    " 3450 en 2500 v.Chr."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "Deeben J. e.a. (red.) 2005, De Steentijd van Nederland, Zutphen."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/108",
    },
    {
        "id": 60,
        "labels": [{"label": "stijlen", "language": "nl-BE", "type": "prefLabel"}],
        "member_of": [],
        "members": [
            1,
            3,
            4,
            5,
            7,
            8,
            9,
            10,
            11,
            20,
            21,
            22,
            23,
            25,
            26,
            27,
            28,
            30,
            31,
            35,
            123,
        ],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/60",
    },
    {
        "broader": [],
        "id": 109,
        "labels": [
            {"label": "swifterbantcultuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De Swifterbantcultuur ontstaat aan het begin van het neolithicum."
                    " Het Atlantisch kustgebied wordt gekenmerkd door een verschillend"
                    " gradueel neolithisatieproces. Na de aankomst van LBK in de"
                    " loesszone blijft de bevolking leven volgens het mesolithisch"
                    " principe van jacht en visvangst. De swifterbantcultuur neemt"
                    " mondjesmaat 'neolithische' elementen over en integreert ze in een"
                    " eigen systeem: rond 5000 v.Chr. aardewerk met een typische vorm -"
                    " vanaf dit ogenblik spreken we over de swifterbantcultuur -,"
                    " gedomesticeerde dieren na 4700 v.Chr. en graan ca. 4100 v.Chr. De"
                    " swifterbantcultuur is in Vlaanderen voorlopig enkel gekend in de"
                    " vallei van de beneden-Schelde."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Deeben J. e.a. (red.) 2005, De Steentijd van Nederland,"
                    " Zutphen. \n2) cursusmateriaal UGent (Prof. Ph. Cromb\xe9) \n3)"
                    " VIOE"
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/109",
    },
    {
        "broader": [],
        "id": 110,
        "labels": [
            {"label": "tardenoisiaan", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Tardenoisien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur komt voor vanaf het finaalpaleoltihicum in"
                    " Noordwest-Frankrijk en Belgi\xeb. Karakteristieke artefacten zijn"
                    " de trapeziumvormige pijlpunten. In de rest van Europa komen op"
                    " hetzelfde moment parallelle culturen voor zoals bv. het aziliaan"
                    " in Zuid-Frankrijk en Spanje."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/">https://www.onderzoeksbalans.be/</a>'
                    " \n2) Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van"
                    " Gijn A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/110",
    },
    {
        "broader": [],
        "id": 1,
        "labels": [
            {"label": "traditioneel", "language": "nl-BE", "type": "prefLabel"},
            {
                "label": "bak- en zandsteenstijl",
                "language": "nl-BE",
                "type": "altLabel",
            },
            {"label": "Maasstijl", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [60],
        "narrower": [2],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De traditionele architectuur in Vlaanderen is een architectuur in"
                    " baksteen of in vakwerk.\nHet bakstenen metselwerk wordt"
                    " gecombineerd met natuurstenen elementen (bv. voor de plint, rond"
                    " de gevelopeningen, aan de kroonlijst, ...), terwijl in het"
                    " interieur houten draagconstructies voorkomen. Deze gebouwen"
                    " bezitten zadeldaken, vaak met trapgevels. Ook enkel schaars"
                    " bewaarde voorbeelden met houten gevels kunnen beschouwd worden"
                    " als traditionele stijl."
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/03/2015: SN aangevuld met houten gevels",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/1",
    },
    {
        "broader": [],
        "id": 112,
        "labels": [
            {"label": "trechterbekercultuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "In de 2de fase van het middenneolithicum verschijnt in de regio"
                    " van Polen, Moravi\xeb, Bohemen, Noord- en Oost-Duitsland,"
                    " Denemarken, Zweden, Belgi\xeb en Noord-Nederland de"
                    " trechterbekercultuur. Deze kan gedateerd worden tussen 4350 en"
                    " 2800/2700 v.Chr. en wordt gekenmerkt door trechtervormige vazen."
                    " De cultuur verschilt per regio, maar wordt over het algemeen"
                    " gekenmerkt door vroege domesticatie van dieren en planten,"
                    " gepolijst (vuur)stenen gereedschap, flessen met halzen, manden,"
                    " potten, trechterbekers verfraaid met verticale en horizontale"
                    " groeven en in sommige regio's megalithische grafmonumenten"
                    " (hunnebedden). De trechterbekercultuur treft men ook aan op"
                    " gronden die voor het eerst in gebruik genomen worden voor de"
                    " landbouw."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van"
                    " Gijn A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                    " \n3) cursusmateriaal UGent (Prof. Ph. Cromb\xe9)"
                ),
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/112",
    },
    {
        "broader": [],
        "id": 121,
        "labels": [
            {"label": "urnenveldencultuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [63],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "De urnenveldencultuur kan gedateerd worden tussen 1050 en 800"
                    " v.Chr. (late bronstijd tot vroege ijzertijd). Het hoofdkenmerk"
                    " van de urnenveldencultuur is de veralgemening van de crematie bij"
                    " behandeling van de dode, de depositie van de crematieresten in"
                    " een urne en de plaatsing van de urne in vlakgraven in"
                    " uitgestrekte grafvelden (honderden graven)."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) cursusmateriaal UGent (Prof. J. Bourgeois) \n2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/121",
    },
    {
        "broader": [1],
        "id": 2,
        "labels": [{"label": "vakwerkbouw", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Bouw in houten stijl- en regelwerk. De open ruimtes worden gevuld"
                    " met vitswerk (tenen gevlochten omheen vitslatten) waarop leem"
                    " gesmeerd wordt. De vullingen kunnen ook bestaan uit baksteen."
                ),
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Ook versteende vakwerkbouw is opgenomen in de Databank Bouwkundig"
                    " Erfgoed."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de"
                    " westerse architectuur- en bouwhistorie: bouwkundige termen,"
                    " Leiden, 2005."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/2",
    },
    {
        "broader": [],
        "id": 113,
        "labels": [
            {"label": "vlaardingencultuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [62],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": (
                    "Deze cultuur komt voornamelijk voor in Nederland (langsheen kust),"
                    " maar kent ook enkele sites in Belgi\xeb. Deze cultuur kent"
                    " mogelijk zijn oorsprong in de hazendonkgroep en de"
                    " swifterbantcultuur (technologische overeenkomsten). Ze heeft"
                    " echter wel eigen aardewerkvormen en versiering ontbreekt. Deze"
                    " traditie kan gedateerd worden tussen 3400 en 2500 v.Chr."
                ),
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": (
                    "1) Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van"
                    " Gijn A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                    " \n2) Deeben J. e.a. (red.) 2005, De Steentijd van Nederland,"
                    " Zutphen."
                ),
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/stijlen_en_culturen/113",
    },
]



import subprocess
from pathlib import Path

from hatchling.builders.hooks.plugin.interface import BuildHookInterface


class BuildHook(BuildHookInterface):
    def initialize(self, version: str, build_data) -> None:
        """Execute compilations when building the wheel."""
        super().initialize(version, build_data)

        self.build_frontend()
        self.compile_message_catalog()

    def compile_message_catalog(self):
        root_dir = Path(__file__).parent
        subprocess.run(
            [
                'pybabel',
                'compile',
                '--directory',
                'atramhasis/locale',
                '--domain',
                'atramhasis',
            ],
            cwd=root_dir,
            check=True,
        )

    def build_frontend(self):
        root_dir = Path(__file__).parent
        static = root_dir / 'atramhasis' / 'static'
        static_admin = static / 'admin'
        subprocess.run(['npm', 'install'], cwd=static, check=True)
        subprocess.run(['npm', 'install'], cwd=static_admin, check=True)
        subprocess.run(['grunt', '-v', 'build'], cwd=static_admin, check=True)
